@@ -25,10 +25,15 @@ template<>
 inline StatusWithReason fromString(const std::string& from,
     pdal::expr::ConditionalExpression& expr)
 {
+    std::string error;
+
     expr::Lexer lexer(from);
     expr::ConditionalParser parser(lexer);
-    bool ok = parser.expression(expr) && parser.checkEnd();
-    return { ok ? 0 : -1, parser.error() };
+    if (!parser.expression(expr))
+        return { -1, parser.error() };
+    if (!parser.checkEnd())
+        return { -1, "Found '" + from.substr(lexer.pos()) + "' following valid expression." };
+    return {};
 }
 
 } // namespace Util
