@@ -1,18 +1,18 @@
 #pragma once
 
-#include "BaseParser.hpp"
+#include "MathParser.hpp"
 
 namespace pdal
 {
 namespace expr
 {
 
-class ConditionalParser : public BaseParser
+class ConditionalParser : public MathParser
 {
 public:
-    ConditionalParser(Lexer& lexer) : BaseParser(lexer)
+    ConditionalParser(Lexer& lexer) : MathParser(lexer)
     {}
-    bool expression(Expression& expr);
+    bool expression(Expression& expr) override;
 
 protected:
     bool orexpr(Expression& expr);
@@ -20,7 +20,6 @@ protected:
     bool notexpr(Expression& expr);
     bool primarylogexpr(Expression& expr);
     bool compareexpr(Expression& expr);
-    bool parexpr(Expression& expr);
     bool function1(Expression& expr);
 };
 
