@@ -204,7 +204,7 @@ void LasReader::addArgs(ProgramArgs& args)
 static StaticPluginInfo const s_info {
     "readers.las",
     "ASPRS LAS 1.0 - 1.4 read support",
-    "http://pdal.io/stages/readers.las.html",
+    "https://pdal.org/stages/readers.las.html",
     { "las", "laz" }
 };
 
